#ifndef DEFINE_ISLIB_LOGIT_HPP

#define DEFINE_ISLIB_LOGIT_HPP

namespace islib
  {
    //
    // Declaration of function
    //
    double logit ( double );
  }

#endif // DEFINE_ISLIB_LOGIT_HPP

//
// End of file
//
